OC.L10N.register(
    "federatedfilesharing",
    {
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Pasidalink su manimi per #ownCloud padebesius, plačiau %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Pasidalink su manimi per #ownCloud padebesius",
    "Federated Cloud Sharing" : "Viešas dalijimasis padebesiu",
    "Open documentation" : "Atidaryti dokumentą",
    "Allow users on this server to send shares to other servers" : "Leisti vartotojams šiame serveryje dalintis su kitais serveriais",
    "Allow users on this server to receive shares from other servers" : "Leisti vartotojams šiame serveryje priimti dalijimusis iš kitų serverių",
    "Federated Cloud" : "Viešas debesis",
    "Your Federated Cloud ID:" : "Tavo debesies ID:",
    "Share it:" : "Pasidalink:",
    "Add to your website" : "Pridėti tavo puslapį",
    "Share with me via ownCloud" : "Pasidalink su manimi per ownCloud",
    "HTML Code:" : "HTML kodas:",
    "Add to your ownCloud" : "Pridėti prie tavo ownCloud"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
